'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');

const ReduxStore = Symbol('redux');

const useStore = () => {
  const store = vue.inject(ReduxStore);
  assert(store, 'Warning: no redux store was provided.\n\nPlease provide store preferably with vue install\n\napp.provide(ReduxStore, store)\n\nLearn more about vue-redux-hooks: https://github.com/PatrykWalach/vue-redux-hooks');
  return store;
};

function assert(condition, message) {
  if (!condition) {
    console.error(message);
  }
}

const useSelector = select => {
  const {
    subscribe,
    getState
  } = useStore();
  const selector = vue.ref(select(getState()));
  const unsubscribe = subscribe(() => {
    const nextState = select(getState());
    selector.value = nextState;
  });
  vue.onBeforeUnmount(unsubscribe);
  return vue.computed(() => selector.value);
};

const useDispatch = () => {
  const {
    dispatch
  } = useStore();
  return dispatch;
};

exports.ReduxStore = ReduxStore;
exports.useDispatch = useDispatch;
exports.useSelector = useSelector;
exports.useStore = useStore;
//# sourceMappingURL=index.js.map
