import { inject, ref, onBeforeUnmount, computed } from 'vue';

const ReduxStore = Symbol('redux');

const useStore = () => {
    const store = inject(ReduxStore);
    assert(store, 'Warning: no redux store was provided.\n\nPlease provide store preferably with vue install\n\napp.provide(ReduxStore, store)\n\nLearn more about vue-redux-hooks: https://github.com/PatrykWalach/vue-redux-hooks');
    return store;
};
function assert(condition, message) {
    if (!condition) {
        console.error(message);
    }
}

const useSelector = (select) => {
    const { subscribe, getState } = useStore();
    const selector = ref(select(getState()));
    const unsubscribe = subscribe(() => {
        const nextState = select(getState());
        selector.value = nextState;
    });
    onBeforeUnmount(unsubscribe);
    return computed(() => selector.value);
};

const useDispatch = () => {
    const { dispatch } = useStore();
    return dispatch;
};

export { ReduxStore, useDispatch, useSelector, useStore };
//# sourceMappingURL=index.js.map
